@@ -29,5 +29,16 @@ from .french import French
 from .english import English
 from .spanish import Spanish
 from .portuguese import Portuguese
+from .german import German
+from .catalan import Catalan
+from .russian import Russian
 
-LANG = {"fr": French(), "en": English(), "es": Spanish(), "pt": Portuguese()}
+LANG = {
+    "fr": French(),
+    "en": English(),
+    "es": Spanish(),
+    "pt": Portuguese(),
+    "de": German(),
+    "ca": Catalan(),
+    "ru": Russian(),
+}
